<?xml version="1.0" encoding="UTF-8"?>
<!-- fz813_584v1.0_VALXSLTu1, september-2023 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:fz813="http://ei.vektis.nl/verantwoording/fz813"
xmlns:fz814="http://ei.vektis.nl/verantwoording/fz814">

	<!-- VALXSLT 2 TRAPS RETOURBERICHT  - versie Vecozo -->
	<!-- Deze xslt doet stap 1, i.e. tussenresultaat retourbericht met alle klassen, identificerende gegevens van klassen en geconstateerde fouten -->
	<!-- Laden Configuratiefile met waarde voor Omgeving en Huidige datum	-->

	<xsl:import href="config_Vecozo.xml"/>
	<xsl:import href="rcCode_vs_Peildatum.xslt"/>
	<xsl:import href="rcDatum_vs_Peildatum.xslt"/>
	<xsl:import href="rcDatum_vs_Huidigedatum.xslt"/>
 	<xsl:import href="rc8028.xslt"/>
 	<xsl:import href="rc8049.xslt"/>
	<xsl:import href="rc9262a.xslt"/>
	<xsl:import href="rc9263a.xslt"/>
 	<xsl:import href="rc9620.xslt"/>
 	<xsl:import href="rc9622.xslt"/>
 	<xsl:import href="rc9623.xslt"/>
	<xsl:import href="rc9638.xslt"/>

	<!-- Uitvoer is fz814_585 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />

	<xsl:variable name="Berichtcode" select="//fz813:Bericht/fz813:Header/fz813:Berichtcode"/> 
	<xsl:variable name="Berichtsoort" select="//fz813:Bericht/fz813:Header/fz813:Berichtsoort"/> 
	<xsl:variable name="Verzenddatum" select="//fz813:Bericht/fz813:Header/fz813:Verzenddatum"/>
	<xsl:variable name="VerzenderRol" select="//fz813:Bericht/fz813:Header/fz813:VerzenderRol"/>
	<xsl:variable name="OntvangerRol" select="//fz813:Bericht/fz813:Header/fz813:OntvangerRol"/> 
	<xsl:variable name="ZorgaanbiederSoort" select="//fz813:Bericht/fz813:VerantwoordingsContext/fz813:Instelling/fz813:ZorgaanbiederSoort"/>
	<xsl:variable name="EinddatumVerantwoordingsperiode" select="//fz813:Bericht/fz813:VerantwoordingsContext/fz813:EinddatumVerantwoordingsperiode"/>
	<xsl:variable name="TotaalAngZpmBedrag" select="//fz813:Bericht/fz813:Overzicht/fz813:TotaalAngZpm/fz813:Bedrag"/>
	<xsl:variable name="TotaalAngZpmDCIndicator" select="//fz813:Bericht/fz813:Overzicht/fz813:TotaalAngZpm/fz813:DebetCreditCode"/>
		
	<!-- Controleer op fouten in de Header -->
	<!-- RC003: VerzenderRol moet voorkomen in ketenpartij codelijst. | Indien VerzenderRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van VerzenderRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van VerzenderRol. -->
	<xsl:variable name="rc003">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9302'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9303'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9304'"/>
			<xsl:with-param name="Code" select="$VerzenderRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- RC006: OntvangerRol moet voorkomen in ketenpartij codelijst. | Indien OntvangerRol in ketenpartij voorkomt, dan moet de waarde van Verzenddatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum ketenpartij van OntvangerRol. | Indien expiratiedatum ketenpartij gevuld is, dan moet de waarde van Verzenddatum kleiner zijn dan de waarde van expiratiedatum ketenpartij van OntvangerRol. -->
	<xsl:variable name="rc006">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/CL0002-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9311'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'9312'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'9313'"/>
			<xsl:with-param name="Code" select="$OntvangerRol"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC001: De waarde van Berichtsoort moet voldoen aan de omgeving van VECOZO (productie of test) -->
	<xsl:variable name="vc001">
		<xsl:call-template name="rc8028">
			<xsl:with-param name="Berichtsoort" select="$Berichtsoort"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC002: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM), dan mag alleen VerzenderRol = 1 (= Zorgaanbieder) of 2 (= Servicebureau) voorkomen. -->
	<xsl:variable name="vc002">
		<xsl:call-template name="rc9262a">
			<xsl:with-param name="Berichtcode" select="$Berichtcode"/>
			<xsl:with-param name="VerzenderRol" select="$VerzenderRol"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC004: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM),dan mag alleen OntvangerRol = 2 (= Servicebureau), 4 (= DJI) voorkomen. -->
	<xsl:variable name="vc004">
		<xsl:call-template name="rc9263a">
			<xsl:with-param name="Berichtcode" select="$Berichtcode"/>
			<xsl:with-param name="OntvangerRol" select="$OntvangerRol"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC006: De waarde van Verzenddatum moet kleiner zijn dan of gelijk zijn aan de waarde van huidige datum. -->
	<xsl:variable name="vc006">
		<xsl:call-template name="rcDatum_vs_Huidigedatum">
			<xsl:with-param name="TeControlerenDatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'8986'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- Zet variabele als er geen fouten zijn opgetreden in de Header -->
	<xsl:variable name="FoutInHeader">
		<xsl:if test="$rc003='' and $rc006='' and $vc001='' and $vc002='' and $vc004='' and $vc006=''">false</xsl:if>
	</xsl:variable>
		
	<!-- Controleer op fouten in de VerantwoordingsContext -->
	<!-- VC007: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM),dan mag alleen ZorgaanbiederSoort = 1 (= Instelling) voorkomen. -->
	<xsl:variable name="vc007">
		<xsl:call-template name="rc9620">
			<xsl:with-param name="Berichtcode" select="$Berichtcode"/>
			<xsl:with-param name="ZorgaanbiederSoort" select="$ZorgaanbiederSoort"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- VC008: De waarde van EinddatumVerantwoordingsperiode moet kleiner zijn dan of gelijk zijn aan de waarde van huidige datum. -->
	<xsl:variable name="vc008">
		<xsl:call-template name="rcDatum_vs_Peildatum">
			<xsl:with-param name="TeControlerenDatum" select="$EinddatumVerantwoordingsperiode"/>
			<xsl:with-param name="Peildatum" select="$Verzenddatum"/>
			<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
			<xsl:with-param name="Retourcode" select="'9636'"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- Zet variabele als er geen fouten zijn opgetreden in de VerantwoordingsContext -->
	<xsl:variable name="FoutInVerantwoordingsContext">
		<xsl:if test="$vc007='' and $vc008=''">false</xsl:if>
	</xsl:variable>

	<!-- Controleer op fouten in Overzicht -->
	<!-- VC009: Het bedrag in TotaalAngZpm komt niet overeen met de gedeclareerde bedragen in AngZpm. -->
	<xsl:variable name="vc009">
		<xsl:call-template name="rc9622">
			<xsl:with-param name="TotaalAngZpmBedrag" select="$TotaalAngZpmBedrag"/>
			<xsl:with-param name="TotaalAngZpmDCIndicator" select="$TotaalAngZpmDCIndicator"/>
			<xsl:with-param name="TotaalDebetPrestaties" select="sum(//fz813:Bericht/fz813:Plaatsingsbesluit/fz813:AngZpm/fz813:DeclaratieBedragInclBtw[fz813:DebetCreditCode = 'D']/fz813:Bedrag)"/>
			<xsl:with-param name="TotaalCreditPrestaties" select="sum(//fz813:Bericht/fz813:Plaatsingsbesluit/fz813:AngZpm/fz813:DeclaratieBedragInclBtw[fz813:DebetCreditCode = 'C']/fz813:Bedrag)"/>
		</xsl:call-template>
	</xsl:variable>
	<!-- controles klasse TotaalAngZpm uitvoeren -->
	<!-- RC010: DebetCreditCode moet voorkomen in Indicatie debet/credit codelijst. -->
	<xsl:variable name="rc010">
		<xsl:call-template name="rcCode_vs_Peildatum">
			<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
			<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
			<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
			<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
			<xsl:with-param name="Code" select="$TotaalAngZpmDCIndicator"/>
			<xsl:with-param name="Peildatum" select="geenpeildatum"/>
		</xsl:call-template>
	</xsl:variable>		
	<!-- Zet variabele als er geen fouten zijn opgetreden in de VerantwoordingsContext -->
	<xsl:variable name="FoutInOverzicht">
		<xsl:if test="$vc009='' and $rc010=''">false</xsl:if>
	</xsl:variable>
		
	<xsl:template match="fz813:Bericht">
		<fz814:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/verantwoording/fz814 fz814_585.xsd</xsl:attribute>
			<xsl:choose>
				<!-- Geen errors in de Header, VerantwoordingsContext of Overzicht dan hele bericht als retour -->
				<xsl:when test="$FoutInHeader='false' and $FoutInVerantwoordingsContext='false' and $FoutInOverzicht='false'">
					<xsl:apply-templates select="fz813:Header"/>
					<xsl:apply-templates select="fz813:VerantwoordingsContext"/>
					<xsl:apply-templates select="fz813:Overzicht"/>
					<xsl:apply-templates select="fz813:Plaatsingsbesluit"/>
  				</xsl:when>
				<!-- Wel errors in de Header, VerantwoordingsContext of Overzicht dan alleen Header, VerantwoordingsContext en Overzicht als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="fz813:Header"/>
					<xsl:apply-templates select="fz813:VerantwoordingsContext"/>
					<xsl:apply-templates select="fz813:Overzicht"/>
				</xsl:otherwise>
			</xsl:choose>				
		</fz814:Bericht>
	</xsl:template>

	<xsl:template match="fz813:Header">
		<fz814:Header>
			<fz814:Berichtcode>585</fz814:Berichtcode>
			<xsl:apply-templates select="fz813:Berichtversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:Berichtsubversie" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:Berichtsoort" mode="copy-if-exists"/>
			<!-- als Vecozo is verzender van het retourbericht dan vullen met gegevens van Vecozo, anders met de gegevens van de verzender van het verantwoordingsbericht -->
			<xsl:choose>
				<xsl:when test="$VerzenderRetourbericht = 'Vecozo'">
					<fz814:VerzenderRol>
						<xsl:value-of select="$VerzenderRolVecozo"/>
					</fz814:VerzenderRol>
				</xsl:when>
				<xsl:otherwise>
					<fz814:Verzender><xsl:value-of select="fz813:Ontvanger"/></fz814:Verzender>
					<fz814:VerzenderRol><xsl:value-of select="fz813:OntvangerRol"/></fz814:VerzenderRol>
				</xsl:otherwise>
			</xsl:choose>
			<!-- Ontvanger in retourbericht is Verzender uit verantwoordingsbericht -->
			<fz814:Ontvanger><xsl:value-of select="fz813:Verzender"/></fz814:Ontvanger>
			<!-- OntvangerRol in retourbericht is VerzenderRol uit verantwoordingsbericht -->
			<fz814:OntvangerRol><xsl:value-of select="fz813:VerzenderRol"/></fz814:OntvangerRol>
			<fz814:Verzenddatum><xsl:value-of select="$HuidigeDatum"/></fz814:Verzenddatum>
			<!-- als Referentienummer van retourbericht het Referentienummer van verantwoordingsbericht hanteren -->
			<xsl:apply-templates select="fz813:Referentienummer" mode="copy-if-exists"/>
			<!-- feedback klasse Header toevoegen -->
			<xsl:copy-of select="$rc003"/>
			<xsl:copy-of select="$rc006"/>
			<xsl:copy-of select="$vc001"/>
			<xsl:copy-of select="$vc002"/>
			<xsl:copy-of select="$vc004"/>
			<xsl:copy-of select="$vc006"/>
		</fz814:Header>
	</xsl:template>
		
	<xsl:template match="fz813:VerantwoordingsContext">	
		<fz814:VerantwoordingsContext>
			<xsl:apply-templates select="fz813:Instelling"/>
			<xsl:apply-templates select="fz813:EinddatumVerantwoordingsperiode" mode="copy-if-exists"/>
			<!-- feedback klasse VerantwoordingsContext toevoegen -->
			<xsl:copy-of select="$vc007"/>
			<xsl:copy-of select="$vc008"/>
		</fz814:VerantwoordingsContext>
	</xsl:template>				

	<xsl:template match="fz813:Instelling">	
		<fz814:Instelling>
			<xsl:apply-templates select="fz813:Zorgaanbiedercode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:ZorgaanbiederSoort" mode="copy-if-exists"/>
		</fz814:Instelling>
	</xsl:template>			

	<xsl:template match="fz813:Overzicht">	
		<fz814:Overzicht>
			<xsl:apply-templates select="fz813:TotaalAngZpm"/>
			<!-- feedback klasse VerantwoordingsContext toevoegen -->
			<xsl:copy-of select="$vc009"/>
			<xsl:copy-of select="$rc010"/>
		</fz814:Overzicht>
	</xsl:template>				

	<xsl:template match="fz813:TotaalAngZpm">	
		<fz814:TotaalAngZpm>
			<xsl:apply-templates select="fz813:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:DebetCreditCode" mode="copy-if-exists"/>
		</fz814:TotaalAngZpm>
	</xsl:template>			
		
	<xsl:template match="fz813:Plaatsingsbesluit">
		<fz814:Plaatsingsbesluit>
			<!-- retourneer identificerende gegevens van Plaatsingsbesluit -->
			<xsl:apply-templates select="fz813:Zorgcontractnummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:PlaatsingsbesluitNummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:Verzekerdennummer" mode="copy-if-exists"/>
			<!-- controles klasse Plaatsingsbesluit uitvoeren, eerst subklasses -->
			<xsl:apply-templates select="fz813:AngZpm"/>
		</fz814:Plaatsingsbesluit>
	</xsl:template>				

	<xsl:template match="fz813:AngZpm">
		<fz814:AngZpm>
			<!-- retourneer identificerende gegevens van AngZpm -->
			<xsl:apply-templates select="fz813:PrestatieCodelijstCode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:Prestatiecode" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:ZorgtrajectNummer" mode="copy-if-exists"/>		
			<xsl:apply-templates select="fz813:Begindatum" mode="copy-if-exists"/>			
			<xsl:apply-templates select="fz813:Begintijd" mode="copy-if-exists"/>
			<xsl:apply-templates select="fz813:Volgnummer" mode="copy-if-exists"/>
			<!-- controles klasse AngZpm uitvoeren, eerst subklasses -->
			<xsl:apply-templates select="fz813:DeclaratieBedragInclBtw"/>			
			<!-- RC008: PrestatieCodelijstCode moet voorkomen in aanduiding prestatiecodelijst codelijst. | Indien PrestatieCodelijstCode in aanduiding prestatiecodelijst voorkomt, dan moet de waarde van Begindatum groter zijn dan of gelijk zijn aan de waarde van ingangsdatum aanduiding prestatiecodelijst van PrestatieCodelijstCode. | Indien expiratiedatum aanduiding prestatiecodelijst gevuld is, dan moet de waarde van Begindatum kleiner zijn dan de waarde van expiratiedatum aanduiding prestatiecodelijst van PrestatieCodelijstCode. -->
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD367-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9633'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'9634'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'9635'"/>
				<xsl:with-param name="Code" select="fz813:PrestatieCodelijstCode"/>
				<xsl:with-param name="Peildatum" select="fz813:Begindatum"/>
			</xsl:call-template>
			<!-- VC010: Indien Berichtcode = 584 (= Verantwoording forensische zorg voor ZPM), dan moet PrestatieCodelijstCode = 071 (= Prestatiecodelijst geestelijke gezondheidszorg en forensische zorg volgens ZPM) voorkomen. -->
				<xsl:call-template name="rc9623">
					<xsl:with-param name="Berichtcode" select="$Berichtcode"/>
					<xsl:with-param name="PrestatieCodelijstCode" select="fz813:PrestatieCodelijstCode"/>
				</xsl:call-template>
			<!-- VC011: De waarde van Begindatum moet kleiner zijn dan of gelijk zijn aan de waarde van EinddatumVerantwoordingsperiode -->
				<xsl:call-template name="rcDatum_vs_Peildatum">
					<xsl:with-param name="TeControlerenDatum" select="fz813:Begindatum"/>
					<xsl:with-param name="Peildatum" select="$EinddatumVerantwoordingsperiode"/>
					<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
					<xsl:with-param name="Retourcode" select="'9624'"/>
				</xsl:call-template>
			<!-- VC012: Indien Einddatum voorkomt, dan moet de waarde van Begindatum kleiner zijn dan de waarde van Einddatum. -->
				<xsl:call-template name="rcDatum_vs_Peildatum">
					<xsl:with-param name="TeControlerenDatum" select="fz813:Einddatum"/>
					<xsl:with-param name="Peildatum" select="fz813:Begindatum"/>
					<xsl:with-param name="Vergelijking" select="'groterdan'"/>
					<xsl:with-param name="Retourcode" select="'9458'"/>
				</xsl:call-template>
			<!-- VC013: Indien Einddatum voorkomt, dan moet de waarde van Einddatum kleiner zijn dan of gelijk zijn aan de waarde van EinddatumVerantwoordingsperiode -->
				<xsl:call-template name="rcDatum_vs_Peildatum">
					<xsl:with-param name="TeControlerenDatum" select="fz813:Einddatum"/>
					<xsl:with-param name="Peildatum" select="$EinddatumVerantwoordingsperiode"/>
					<xsl:with-param name="Vergelijking" select="'kleinerofgelijkaan'"/>
					<xsl:with-param name="Retourcode" select="'9625'"/>
				</xsl:call-template>
			<!-- VC014: Indien Prestatiecodelijst = 071 (= Prestatiecodelijst geestelijke gezondheidszorg en forensische zorg volgens ZPM), dan moet Aantal gelijk zijn aan ‘1’. -->
			<xsl:call-template name="rc8049">
				<xsl:with-param name="Aantal" select="fz813:Aantal"/>
				<xsl:with-param name="PrestatieCodelijstCode" select="fz813:PrestatieCodelijstCode"/>
			</xsl:call-template>
			<!-- VC015: BegindatumPrestatie mag niet voor 1 januari van het jaar van de EinddatumVerantwoordingsperiode liggen.. -->
			<xsl:call-template name="rc9638">
				<xsl:with-param name="Begindatum" select="fz813:Begindatum"/>
				<xsl:with-param name="EinddatumVerantwoordingsperiode" select="$EinddatumVerantwoordingsperiode"/>
			</xsl:call-template>
		</fz814:AngZpm>
	</xsl:template>

	<xsl:template match="fz813:DeclaratieBedragInclBtw">	
		<fz814:DeclaratieBedragInclBtw>
			<!-- controles klasse DeclaratieBedragInclBtw uitvoeren, eerst subklasses -->
			<!-- RC010: DebetCreditCode moet voorkomen in Indicatie debet/credit. -->				
			<xsl:call-template name="rcCode_vs_Peildatum">
				<xsl:with-param name="Codelijst" select="'codelijsten/COD043-VEKT.xml'"/>
				<xsl:with-param name="RetourcodeBestaanbaarheid" select="'9406'"/>
				<xsl:with-param name="RetourcodeIngangsdatum" select="'nvt'"/>
				<xsl:with-param name="RetourcodeExpiratiedatum" select="'nvt'"/>
				<xsl:with-param name="Code" select="fz813:DebetCreditCode"/>
				<xsl:with-param name="Peildatum" select="geenpeildatum"/>
			</xsl:call-template>
		</fz814:DeclaratieBedragInclBtw>
	</xsl:template>			
		
	<!-- Copy template: als een enkel element voorkomt, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="*[namespace-uri()='http://ei.vektis.nl/verantwoording/fz813']" mode="copy-if-exists">
		<xsl:if test=".">
			<xsl:element name="{concat('fz814:',local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>