<?xml version="1.0" encoding="UTF-8"?>
<!-- rcCode_vs_Peildatum.xslt, 7 juli 2023 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:cod="http://ei.vektis.nl/codelijsten/v1"
xmlns:fz814="http://ei.vektis.nl/verantwoording/fz814">
		
	<!-- deze routine voert de volgende controle uit: 
		 	- als Code een waarde bevat
				- controleer of Code voorkomt in de codelijst met bestandsnaam Codelijst; als Code niet voorkomt, dan wordt retourcode RetourcodeBestaanbaarheid geretourneerd; geen verdere controles
				- als Peildatum een waarde bevat
					- controleer of de ingangsdatum van Code kleiner of gelijk aan Peildatum is; als dit niet het geval is, dan wordt retourcode RetourcodeIngangsdatum geretourneerd
					- als Code een expiratiedatum heeft, controleer of Peildatum voor de expiratiedatum ligt; als dit niet het geval is, dan wordt retourcode RetourcodeExpiratiedatum geretourneerd -->
	
	<xsl:template name="rcCode_vs_Peildatum">
		<xsl:param name="Codelijst"/>
		<xsl:param name="RetourcodeBestaanbaarheid"/>
		<xsl:param name="RetourcodeIngangsdatum"/>
		<xsl:param name="RetourcodeExpiratiedatum"/>
		<xsl:param name="Code"/>
		<xsl:param name="Peildatum"/>
		
		<!-- als Code een waarde bevat, controleer Code -->
		<xsl:if test="$Code != ''">
			<!-- controleer of Code bestaat -->
			<xsl:choose>
				<xsl:when test="not(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code])">
					<fz814:Feedback>
						<fz814:Retourcode><xsl:value-of select="$RetourcodeBestaanbaarheid"/></fz814:Retourcode>
							<!-- som de elementen op die de fout veroorzaken -->
							<fz814:BetrokkenElement>
								<fz814:Elementnaam><xsl:value-of select="local-name($Code)"/></fz814:Elementnaam>
								<fz814:Elementwaarde><xsl:value-of select="$Code"/></fz814:Elementwaarde>
							</fz814:BetrokkenElement>
					</fz814:Feedback>
				</xsl:when>
				<xsl:otherwise>
					<!-- als code bestaat en Peildatum is gevuld, verifieer of Code al bestond op Peildatum (er moet gelden: Ingangsdatum <= Peildatum) -->
					<xsl:if test="$Peildatum != '' and document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum != '' and
								translate($Peildatum,'-','') &lt; translate(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum,'-','')">
						<fz814:Feedback>
							<fz814:Retourcode><xsl:value-of select="$RetourcodeIngangsdatum"/></fz814:Retourcode>
								<!-- som de elementen op die de fout veroorzaken -->
								<fz814:BetrokkenElement>
									<fz814:Elementnaam><xsl:value-of select="local-name($Code)"/></fz814:Elementnaam>
									<fz814:Elementwaarde><xsl:value-of select="$Code"/></fz814:Elementwaarde>
								</fz814:BetrokkenElement>
								<fz814:BetrokkenElement>
									<fz814:Elementnaam><xsl:value-of select="local-name($Peildatum)"/></fz814:Elementnaam>
									<fz814:Elementwaarde><xsl:value-of select="$Peildatum"/></fz814:Elementwaarde>
								</fz814:BetrokkenElement>
								<fz814:BetrokkenElement>
									<fz814:Elementnaam><xsl:value-of select="name(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum)"/></fz814:Elementnaam>
									<fz814:Elementwaarde><xsl:value-of select="document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Ingangsdatum"/></fz814:Elementwaarde>
								</fz814:BetrokkenElement>
						</fz814:Feedback>
					</xsl:if>
					<!-- als code bestaat en Peildatum is gevuld, verifieer of Code niet is geëxpireerd op Peildatum (er moet gelden: Peildatum < Expiratiedatum) -->
					<xsl:if test="$Peildatum != '' and document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum != '' and 
								not(translate($Peildatum,'-','') &lt; translate(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum,'-',''))">
						<fz814:Feedback>
							<fz814:Retourcode><xsl:value-of select="$RetourcodeExpiratiedatum"/></fz814:Retourcode>
								<!-- som de elementen op die de fout veroorzaken -->
								<fz814:BetrokkenElement>
									<fz814:Elementnaam><xsl:value-of select="local-name($Code)"/></fz814:Elementnaam>
									<fz814:Elementwaarde><xsl:value-of select="$Code"/></fz814:Elementwaarde>
								</fz814:BetrokkenElement>
								<fz814:BetrokkenElement>
									<fz814:Elementnaam><xsl:value-of select="local-name($Peildatum)"/></fz814:Elementnaam>
									<fz814:Elementwaarde><xsl:value-of select="$Peildatum"/></fz814:Elementwaarde>
								</fz814:BetrokkenElement>
								<fz814:BetrokkenElement>
									<fz814:Elementnaam><xsl:value-of select="name(document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum)"/></fz814:Elementnaam>
									<fz814:Elementwaarde><xsl:value-of select="document($Codelijst)/cod:Codelijst/cod:CodelijstElement[cod:Code=$Code]/cod:Expiratiedatum"/></fz814:Elementwaarde>
								</fz814:BetrokkenElement>
						</fz814:Feedback>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
